# sachin-chess-utils

General propose Chess related utility functions.

# Build

python3 setup.py sdist bdist_wheel

# Local Test

pip install dist/sachin_chess_utils-0.1.1-py3-none-any.whlhttps://www.youtube.com/watch?v=Kz6IlDCyOUY&t=377s&ab_channel=pixegami

# Publish

twine upload dist/\*
